==> jc-1.4.0.tar.gz: java/util/EventObject.h <==
// public class java.util.EventObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_EventObject_H_
#define _JC_java_util_EventObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_EventObject$sub_refs	_jc_java_util_EventObject$sub_refs;
typedef struct _jc_java_util_EventObject$sub_nonrefs	_jc_java_util_EventObject$sub_nonrefs;
typedef struct _jc_java_util_EventObject$refs	_jc_java_util_EventObject$refs;
typedef struct _jc_java_util_EventObject$nonrefs	_jc_java_util_EventObject$nonrefs;
typedef struct _jc_java_util_EventObject$object	_jc_java_util_EventObject$object;

typedef struct _jc_java_util_EventObject$fields_struct	_jc_java_util_EventObject$fields_struct;
typedef const struct _jc_java_util_EventObject$vmethods	_jc_java_util_EventObject$vmethods;
typedef const struct _jc_java_util_EventObject$vtable	_jc_java_util_EventObject$vtable;
typedef const struct _jc_java_util_EventObject$vtype	_jc_java_util_EventObject$vtype;

// Class fields structure
struct _jc_java_util_EventObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_EventObject$fields_struct _jc_java_util_EventObject$class_fields;

// Constructors
extern void _jc_java_util_EventObject$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_util_EventObject$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_util_EventObject$method$getSource$b11b93305f9d301e(_jc_env *, struct _jc_java_util_EventObject$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_EventObject$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_EventObject$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_EventObject$method_info$getSource$b11b93305f9d301e;
extern _jc_method _jc_java_util_EventObject$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_EventObject$vmethods {
	struct _jc_java_lang_Object$object	*(*getSource$b11b93305f9d301e)(_jc_env *, struct _jc_java_util_EventObject$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_EventObject$object *);
};

// Vtable
struct _jc_java_util_EventObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
};

// Vtype
struct _jc_java_util_EventObject$vtype {
	_jc_type			type;
	_jc_java_util_EventObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_EventObject$sub_refs {
	struct _jc_java_lang_Object$object	*source;
};

// Reference instance fields (object)
struct _jc_java_util_EventObject$refs {
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_EventObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_EventObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
};

// Object instance structure
struct _jc_java_util_EventObject$object {
	_jc_java_util_EventObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_EventObject$vtype	*vtype;
	_jc_java_util_EventObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_EventObject$vtype _jc_java_util_EventObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_EventObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_EventObject$class_object;

#endif	/* _JC_java_util_EventObject_H_ */

==> jc-1.4.6.tar.gz: java/util/EventObject.h <==
// public class java.util.EventObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_EventObject_H_
#define _JC_java_util_EventObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_EventObject$sub_refs	_jc_java_util_EventObject$sub_refs;
typedef struct _jc_java_util_EventObject$sub_nonrefs	_jc_java_util_EventObject$sub_nonrefs;
typedef struct _jc_java_util_EventObject$refs	_jc_java_util_EventObject$refs;
typedef struct _jc_java_util_EventObject$nonrefs	_jc_java_util_EventObject$nonrefs;
typedef struct _jc_java_util_EventObject$object	_jc_java_util_EventObject$object;

typedef struct _jc_java_util_EventObject$fields_struct	_jc_java_util_EventObject$fields_struct;
typedef const struct _jc_java_util_EventObject$vmethods	_jc_java_util_EventObject$vmethods;
typedef const struct _jc_java_util_EventObject$vtable	_jc_java_util_EventObject$vtable;
typedef const struct _jc_java_util_EventObject$vtype	_jc_java_util_EventObject$vtype;

// Class fields structure
struct _jc_java_util_EventObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_EventObject$fields_struct _jc_java_util_EventObject$class_fields;

// Constructors
extern void _jc_java_util_EventObject$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_util_EventObject$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_util_EventObject$method$getSource$b11b93305f9d301e(_jc_env *, struct _jc_java_util_EventObject$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_EventObject$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_EventObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_EventObject$method_info$getSource$b11b93305f9d301e;
extern _jc_method _jc_java_util_EventObject$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_EventObject$vmethods {
	struct _jc_java_lang_Object$object	*(*getSource$b11b93305f9d301e)(_jc_env *, struct _jc_java_util_EventObject$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_EventObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_EventObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
};

// Vtype
struct _jc_java_util_EventObject$vtype {
	_jc_type			type;
	_jc_java_util_EventObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_EventObject$sub_refs {
	struct _jc_java_lang_Object$object	*source;
};

// Reference instance fields (object)
struct _jc_java_util_EventObject$refs {
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_EventObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_EventObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
};

// Object instance structure
struct _jc_java_util_EventObject$object {
	_jc_java_util_EventObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_EventObject$vtype	*vtype;
	_jc_java_util_EventObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_EventObject$vtype _jc_java_util_EventObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_EventObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_EventObject$class_object;

#endif	/* _JC_java_util_EventObject_H_ */
